@@ -116,8 +116,7 @@ class Project():
         execfile(os.path.join(venvdir,'bin/activate_this.py'))
         return
 
-
-def copy_project_skel(project_path):
+    def copy_project_skel(project_path):
     """Populate a (usually) new backstage project with the contents of backstage/skel"""
     skeldir = os.path.join(os.path.dirname(backstage.__file__),'skel')
     if not os.path.exists(skeldir):
@@ -125,9 +124,8 @@ def copy_project_skel(project_path):
         print s
         raise
     try:
-        #Copy the contents of the 'base' folder into the project root
-        skelbase=os.path.join(skeldir, 'base')
-        os.system("cp -rpv %s/* %s" % (skelbase, project_path))
+        #Copy the contents of the 'skel' folder into the project root
+        os.system("cp -rpv %s/* %s" % (skeldir, project_path))
 
     except:
         s = "ERROR copying the project skel into %s" % project_path
@@ -135,6 +133,8 @@ def copy_project_skel(project_path):
         raise
     return True
 
+
+
 def new_project(project_name, project_path, source_ini_file = None):
         """create a new backstage project with the given name and located at the specified path"""
         project_path = os.path.abspath(os.path.join(project_path, project_name))
