@@ -1,3 +1,5 @@
+import gettext
+
 ALLOWED_HOSTS = []
 
 CACHES = {
@@ -8,6 +10,12 @@ CACHES = {
 
 SECRET_KEY=''
 
+LANGUAGE_CODE = 'en-us'
+ugettext = lambda s: s
+LANGUAGES = (
+    ('en', ugettext('American English')),
+        )
+
 TEMPLATE_DIRS = []
 TEMPLATE_LOADERS = [
     'django.template.loaders.filesystem.Loader',
